## rag utils

```python
pip install raggy
```

### examples
- scraping sitemaps
- putting documents in vectorstores

see this [example](https://github.com/zzstoatzz/raggy/blob/main/examples/refresh_chroma/main.py)
